@@ -9,6 +9,8 @@ TABLES = {
     'pluto_19v2': {'pluto_19v2': 800_000},
     'pluto_20v8': {'pluto_20v8': 800_000},
     'pluto_21v3': {'pluto_21v3': 800_000},
+    'pluto_22v1': {'pluto_22v1': 800_000},
+    'pluto_latest': {'pluto_latest': 800_000},
     'dobjobs': {'dobjobs': 1_000_000},
     'dob_violations': {'dob_violations': 2_000_000},
     'ecb_violations': {'ecb_violations': 1_300_000},
@@ -21,6 +23,7 @@ TABLES = {
         'hpd_registrations_grouped_by_bbl': 130_000,
         'hpd_registrations_grouped_by_bbl_with_contacts': 130_000
     },
+    'dof_421a': {'dof_421a': 275_000},
     'dof_sales': {'dof_sales': 60_000},
     'dof_annual_sales': { 'dof_annual_sales': 900_000 },
     'dof_exemptions': {
